import { http } from '@/utils/http';

/* 获取部门所有人员信息 */
export function listApi(config : object) {
	return http({
		url: '/cxc_rlzy.zb/cxcRlzyZb/list',
		method: 'GET',
		data: config
	})
}

/* 获取工作经历 */
export function workExperienceListApi(ldhth : string) {
	return http({
		url: '/cxc_rlzy.zb/cxcRlzyZb/queryLl',
		method: 'GET',
		data: ldhth
	})
}

export function queryGzjlByRyLdhth(ldhth) { // 获取人员工作经历信息
	return http({
		url: '/cxc_rlzy.zb/cxcRlzyZb/queryLl',
		method: 'GET',
		data: ldhth
	})
}

export function queryQzqkByRyLdhth(ldhth) { // 获取人员证件台账
	return http({
		url: '/cxc_rlzy.zb/cxcRlzyZb/queryZjtz',
		method: 'GET',
		data: ldhth
	})
}

export function queryJtzycyByRyLdhth(ldhth) { // 获取人员家庭主要成员
	return http({
		url: '/cxchrygxxtj/cxcHrYgxxtj/queryJtzycy',
		method: 'GET',
		data: ldhth
	})
}
export function queryXlxxByRyLdhth(ldhth) { // 获取人员学历信息
	return http({
		url: '/cxchrygxxtj/cxcHrYgxxtj/listCxcXlxwxxFbByMainId',
		method: 'GET',
		data: ldhth
	})
}

export function queryGbxxByRyLdhth(ldhth) { // 获取人员干部信息 专业技术等级信息
	return http({
		url: '/cxc_rlzy.gbxx/cxcRlzyGbxx/queryGbxx',
		method: 'GET',
		data: ldhth
	})
}

export function queryZyzgdjByRyLdhth(ldhth) { // 获取人员职业资格等级
	return http({
		url: '/cxc_rlzy.zb/cxcRlzyZb/queryZyzgdj',
		method: 'GET',
		data: ldhth
	})
}


export function queryJxkhByRyLdhth(ldhth) { // 绩效考核信息
	return http({
		url: '/cxc_rlzy.zb/cxcRlzyZb/listCxcRlzyJxkhByMainId',
		method: 'GET',
		data: ldhth
	})
}

export function cxcHrYgxxtj(parm) { // 获取员工信息统计
	return http({
		url: '/cxchrygxxtj/cxcHrYgxxtj/list',
		method: 'GET',
		data: parm
	})
}

export function cxcRyDataTongji(url, parm) { // 员工信息统计
	return http({
		url: url,
		method: 'GET',
		data: parm
	})
}

export function cxcRyDatAstatistics(parm) { // 员工分组统计
	return http({
		url: '/cxc_rlzy.zb/cxcRlzyZb/statistics',
		method: 'GET',
		data: parm
	})
}

export function cxcRyDatAstatisticsCertificate(parm) { // 员工按证件分组统计
	return http({
		url: '/cxc_rlzy.zb/cxcRlzyZb/getStatisticsCertificate',
		method: 'GET',
		data: parm
	})
}

export function cxcRyDatAstatisticsDetails(parm) { // 员工信息统计
	return http({
		url: '/cxc_rlzy.zb/cxcRlzyZb/details',
		method: 'GET',
		data: parm
	})
}

/*新增打卡记录*/
export function clockInApi(data : object) {
	return http({
		url: '/cxc_rlzy.wbxm.wbdk/cxcRlzyWbdk/add',
		method: 'POST',
		data
	})
}